@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+from plone import api
 from Products.Five import BrowserView
 
 
@@ -17,3 +18,6 @@ class BaseRestView(BrowserView):
     def local_filters_query_url(self):
         base_url = self.context.absolute_url()
         return f"{base_url}/@results-filters"
+
+    def get_current_language(self):
+        return api.portal.get_current_language()[:2]
