@@ -4,6 +4,7 @@ from imio.smartweb.core.config import NEWS_URL
 from imio.smartweb.core.contents.sections.views import CarouselOrTableSectionView
 from imio.smartweb.core.utils import batch_results
 from imio.smartweb.core.utils import get_json
+from plone import api
 from Products.CMFPlone.utils import normalizeString
 
 
@@ -15,7 +16,7 @@ class NewsView(CarouselOrTableSectionView):
         max_items = self.context.nb_results_by_batch * self.context.max_nb_batches
         selected_item = f"selected_news_folders={self.context.related_news}"
         specific_related_newsitems = self.context.specific_related_newsitems
-        if specific_related_newsitems is not None:
+        if specific_related_newsitems:
             selected_item = "&".join(
                 [f"UID={newsitem_uid}" for newsitem_uid in specific_related_newsitems]
             )
@@ -27,10 +28,16 @@ class NewsView(CarouselOrTableSectionView):
             "metadata_fields=image_scales",
             "metadata_fields=effective",
             "metadata_fields=UID",
-            "sort_on=effective",
-            "sort_order=descending",
             f"sort_limit={max_items}",
         ]
+        current_lang = api.portal.get_current_language()[:2]
+        if current_lang != "fr":
+            params.append("translated_in_{}=1".format(current_lang))
+        if not specific_related_newsitems:
+            params += [
+                "sort_on=effective",
+                "sort_order=descending",
+            ]
         url = "{}/@search?{}".format(NEWS_URL, "&".join(params))
         json_search_news = get_json(url)
         if (
@@ -47,20 +54,28 @@ class NewsView(CarouselOrTableSectionView):
             item_url = item["@id"]
             item_uid = item["UID"]
             image_url = ""
+            dict_item = {
+                "uid": item_uid,
+                "title": item["title"],
+                "description": item["description"],
+                "category": item["category_title"],
+                "effective": item["effective"],
+                "url": f"{linking_view_url}#/{item_id}?u={item_uid}",
+                "has_image": item["has_leadimage"],
+            }
             if item["has_leadimage"]:
                 scales = item["image_scales"]["image"][0]["scales"]
                 if image_scale in scales:
                     image_url = f"{item_url}/{scales[image_scale]['download']}"
-            results.append(
-                {
-                    "title": item["title"],
-                    "description": item["description"],
-                    "category": item["category_title"],
-                    "effective": item["effective"],
-                    "url": f"{linking_view_url}#/{item_id}?u={item_uid}",
-                    "image": image_url,
-                    "has_image": item["has_leadimage"],
-                }
+                else:
+                    dict_item["bad_scale"] = image_scale
+                    no_scale_so_download = item["image_scales"]["image"][0]["download"]
+                    image_url = f"{item_url}/{no_scale_so_download}"
+            dict_item["image"] = image_url
+            results.append(dict_item)
+        if specific_related_newsitems:
+            results = sorted(
+                results, key=lambda x: specific_related_newsitems.index(x["uid"])
             )
         return batch_results(results, self.context.nb_results_by_batch)
 
