@@ -473,7 +473,7 @@ EventsTypesVocabulary = EventsTypesVocabularyFactory()
 
 
 class EventsFromEntityVocabularyFactory:
-    def __call__(selfself, context=None):
+    def __call__(self, context=None):
         remote_agendas_vocabulary = get_vocabulary(
             "imio.smartweb.vocabulary.RemoteAgendas"
         )
@@ -496,6 +496,7 @@ class EventsFromEntityVocabularyFactory:
             "event_dates.range=min",
             "b_size=1000000",
         ]
+        # Keep default @search endpoint. Don't use @events endpoint.
         url = "{}/@search?{}".format(EVENTS_URL, "&".join(params))
         json_events = get_json(url)
         if json_events is None or len(json_events.get("items", [])) == 0:
@@ -512,7 +513,7 @@ EventsFromEntityVocabulary = EventsFromEntityVocabularyFactory()
 
 
 class NewsItemsFromEntityVocabularyFactory:
-    def __call__(selfself, context=None):
+    def __call__(self, context=None):
         remote_newsfolders_vocabulary = get_vocabulary(
             "imio.smartweb.vocabulary.RemoteNewsFolders"
         )
@@ -547,7 +548,7 @@ NewsItemsFromEntityVocabulary = NewsItemsFromEntityVocabularyFactory()
 
 
 class AvailableInstanceBehaviorsVocabularyFactory:
-    def __call__(selfself, context=None):
+    def __call__(self, context=None):
         sm = getSite().getSiteManager()
         utilities = sm.getUtilitiesFor(ITaxonomy)
         # getGeneratedName is the behavior name.
